" Vim filetype plugin file
" Language: confini

" Quit if a ftplugin file was already loaded
if exists("b:did_ftplugin")
  finish
endif

" Use the cfg plugin, it's similar enough.
runtime! ftplugin/cfg.vim
