" Vim Keymap file for vietnamese through the usual viqr method
" Maintainer: Samuel Thibault <samuel.thibault@ens-lyon.org>
" Last Change: 2006 Jun 17

scriptencoding utf-8

let b:keymap_name = "vietnamese"

loadkeymap
a	a
A	A
a`	à
A`	À
a?	ả
A?	Ả
a~	ã
A~	Ã
a'	á
A'	Á
a.	ạ
A.	Ạ
a(	ă
A(	Ă
a(`	ằ
A(`	Ằ
a(?	ẳ
A(?	Ẳ
a(~	ẵ
A(~	Ẵ
a('	ắ
A('	Ắ
a(.	ặ
A(.	Ặ
a^	â
A^	Â
a^`	ầ
A^`	Ầ
a^?	ẩ
A^?	Ẩ
a^~	ẫ
A^~	Ẫ
a^'	ấ
A^'	Ấ
a^.	ậ
A^.	Ậ
d	d
D	D
dd	đ
Dd	Đ
DD	Đ
e	e
E	E
e`	è
E`	È
e?	ẻ
E?	Ẻ
e~	ẽ
E~	Ẽ
e'	é
E'	É
e.	ẹ
E.	Ẹ
e^	ê
E^	Ê
e^`	ề
E^`	Ề
e^?	ể
E^?	Ể
e^~	ễ
E^~	Ễ
e^'	ế
E^'	Ế
e^.	ệ
E^.	Ệ
i	i
I	I
i`	ì
I`	Ì
i?	ỉ
I?	Ỉ
i~	ĩ
I~	Ĩ
i'	í
I'	Í
i.	ị
I.	Ị
o	o
O	O
o`	ò
O`	Ò
o?	ỏ
O?	Ỏ
o~	õ
O~	Õ
o'	ó
O'	Ó
o.	ọ
O.	Ọ
o^	ô
O^	Ô
o^`	ồ
O^`	Ồ
o^?	ổ
O^?	Ổ
o^~	ỗ
O^~	Ỗ
o^'	ố
O^'	Ố
o^.	ộ
O^.	Ộ
o+	ơ
O+	Ơ
o+`	ờ
O+`	Ờ
o+?	ở
O+?	Ở
o+~	ỡ
O+~	Ỡ
o+'	ớ
O+'	Ớ
o+.	ợ
O+.	Ợ
u	u
U	U
u`	ù
U`	Ù
u?	ủ
U?	Ủ
u~	ũ
U~	Ũ
u'	ú
U'	Ú
u.	ụ
U.	Ụ
u+	ư
U+	Ư
u+`	ừ
U+`	Ừ
u+?	ử
U+?	Ử
u+~	ữ
U+~	Ữ
u+'	ứ
U+'	Ứ
u+.	ự
U+.	Ự
y	y
Y	Y
y`	ỳ
Y`	Ỳ
y?	ỷ
Y?	Ỷ
y~	ỹ
Y~	Ỹ
y'	ý
Y'	Ý
y.	ỵ
Y.	Ỵ
\\d	d
\\D	D
